import pandas as pd
import numpy as np

def execute_backtest(signals, initial_balance=10000, commission=0.001, slippage=0.001):
    positions = pd.DataFrame(index=signals.index)
    positions['position'] = 100 * signals['signal']
    portfolio = positions.multiply(signals['price'], axis=0)
    pos_diff = positions.diff()

    portfolio['holdings'] = positions.multiply(signals['price'], axis=0)
    portfolio['cash'] = initial_balance - (pos_diff.multiply(signals['price'], axis=0)).cumsum()
    portfolio['total'] = portfolio['cash'] + portfolio['holdings']

    return portfolio

def calculate_max_drawdown(series):
    drawdown = series / series.cummax() - 1
    return drawdown.min()

def analyze_performance(portfolio):
    returns = portfolio['total'].pct_change()
    annual_return = returns.mean() * 252
    annual_volatility = returns.std() * np.sqrt(252)
    sharpe_ratio = annual_return / annual_volatility
    max_drawdown = calculate_max_drawdown(portfolio['total'])

    performance = {
        'annual_return': annual_return,
        'annual_volatility': annual_volatility,
        'sharpe_ratio': sharpe_ratio,
        'max_drawdown': max_drawdown
    }

    return performance
