
import requests
import os
import logging
from dotenv import load_dotenv
from updated_utils import get_access_token

logger = logging.getLogger(__name__)
load_dotenv()

def fetch_stock_data():
    url = os.getenv('API_ENDPOINT', 'https://apiportal.koreainvestment.com/apiservice/your_endpoint')
    api_key = get_access_token()

    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    
    try:
        response = requests.get(url, headers=headers)
        response.raise_for_status()
        data = response.json()
    except requests.exceptions.RequestException as e:
        logger.error(f"HTTP request failed: {e}")
        return []
    except ValueError as e:
        logger.error(f"Error parsing JSON: {e}")
        return []

    processed_data = []
    for item in data.get('items', []):
        processed_data.append({
            'date': item.get('date'),
            'price': item.get('price')
        })
    
    return processed_data
