
import os
import smtplib
from email.mime.text import MIMEText
import yaml
import logging

# 로그 설정
logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')

# Correctly set the config file path relative to this script
config_file_path = os.path.join(os.path.dirname(__file__), 'config.yaml')
if not os.path.exists(config_file_path):
    logging.error(f"Config file not found: {config_file_path}")
    raise FileNotFoundError(f"Config file not found: {config_file_path}")

with open(config_file_path, 'r', encoding='utf-8') as file:
    config = yaml.safe_load(file)

email_config = config['email_config']

def send_email(subject, body, to_email):
    try:
        msg = MIMEText(body)
        msg['Subject'] = subject
        msg['From'] = email_config['from_email']
        msg['To'] = to_email

        with smtplib.SMTP(email_config['smtp_server'], email_config['smtp_port']) as server:
            server.starttls()
            server.login(email_config['from_email'], email_config['password'])
            server.sendmail(email_config['from_email'], to_email, msg.as_string())
        logging.info(f"Email sent to {to_email}")
    except Exception as e:
        logging.error(f"Failed to send email: {e}")
        raise

