document.addEventListener("DOMContentLoaded", function() {
    const socket = io.connect(location.protocol + '//' + document.domain + ':' + location.port);

    // Handle investment amount update success
    socket.on('investmentAmountUpdateSuccess', function(data) {
        console.log('Success:', data);
        alert('Investment amount updated successfully');
    });

    // Handle investment amount update failure
    socket.on('investmentAmountUpdateFailed', function(data) {
        console.error('Update failed:', data.error);
        alert('Error: ' + data.error);
    });

    // Handle investment amount input change
    document.getElementById('investment-amount').addEventListener('input', function(event) {
        let investmentAmount = event.target.value.replace(/,/g, '');
        if (!isNaN(investmentAmount) && investmentAmount !== '') {
            investmentAmount = parseInt(investmentAmount);
            event.target.value = formatNumberWithCommas(investmentAmount);
            socket.emit('updateInvestmentAmount', { investmentAmount: investmentAmount });
        } else {
            event.target.value = '';
        }
    });

    // Handle start trading button click
    document.getElementById('start-trading').addEventListener('click', function() {
        socket.emit('startTrading');
        alert('자동매매가 시작되었습니다.');
    });

    // Handle stop trading button click
    document.getElementById('stop-trading').addEventListener('click', function() {
        socket.emit('stopTrading');
        alert('자동매매가 중지되었습니다.');
    });

    // Handle risk level input change
    document.getElementById('risk-level').addEventListener('input', function() {
        const riskValue = this.value;
        document.getElementById('risk-value').innerText = riskValue;
        updateRiskLevel(riskValue);
    });

    function updateRiskLevel(riskValue) {
        console.log('Risk level set to:', riskValue);
        socket.emit('updateRiskLevel', { riskLevel: riskValue });
    }

    // Handle apply investment button click
    document.getElementById('apply-investment').addEventListener('click', function() {
        const investmentAmount = document.getElementById('investment-amount').value;
        alert('Investment amount set to: ' + investmentAmount);
        socket.emit('updateInvestmentAmount', { investmentAmount: investmentAmount });
    });

    // Handle connection
    socket.on('connect', () => {
        console.log('Connected to server');
    });

    // Handle update data event
    socket.on('updateData', (data) => {
        updatePortfolioSummary(data.portfolioData);
    });

    // Update portfolio summary with received data
    function updatePortfolioSummary(data) {
        document.getElementById('initial-investment').innerText = `₩${data.initialInvestment}`;
        document.getElementById('total-value').innerText = `₩${data.totalValue}`;
        document.getElementById('profit-loss').innerText = `₩${data.profitLoss}`;
        document.getElementById('daily-change').innerText = `₩${data.dailyChange} (${data.dailyChangePercent}%)`;
        document.getElementById('overall-change').innerText = `₩${data.overallChange} (${data.overallChangePercent}%)`;
        document.getElementById('num-assets').innerText = data.numAssets;
        document.getElementById('last-update').innerText = data.lastUpdate;

        const dailyChangeElement = document.getElementById('daily-change');
        const overallChangeElement = document.getElementById('overall-change');

        dailyChangeElement.style.color = data.dailyChange >= 0 ? 'green' : 'red';
        overallChangeElement.style.color = data.overallChange >= 0 ? 'green' : 'red';
    }

    // Fetch and render balance data on page load
    async function fetchBalanceData() {
        const response = await fetch('/balance-data');
        const balanceData = await response.json();
        renderBalanceData(balanceData);
    }

    // Render balance data in the table
    function renderBalanceData(data) {
        const tableBody = document.getElementById('balance-table');
        tableBody.innerHTML = ''; // Clear any existing rows

        data.output2.forEach(item => {
            const row = document.createElement('tr');

            const totalAmountCell = document.createElement('td');
            totalAmountCell.textContent = item['dnca_tot_amt'];
            row.appendChild(totalAmountCell);

            const nextDayExcessAmountCell = document.createElement('td');
            nextDayExcessAmountCell.textContent = item['nxdy_excc_amt'];
            row.appendChild(nextDayExcessAmountCell);

            const previousDayExcessAmountCell = document.createElement('td');
            previousDayExcessAmountCell.textContent = item['prvs_rcdl_excc_amt'];
            row.appendChild(previousDayExcessAmountCell);

            const cmaEvaluationAmountCell = document.createElement('td');
            cmaEvaluationAmountCell.textContent = item['cma_evlu_amt'];
            row.appendChild(cmaEvaluationAmountCell);

            const todaysBuyAmountCell = document.createElement('td');
            todaysBuyAmountCell.textContent = item['thdt_buy_amt'];
            row.appendChild(todaysBuyAmountCell);

            const todaysSellAmountCell = document.createElement('td');
            todaysSellAmountCell.textContent = item['thdt_sll_amt'];
            row.appendChild(todaysSellAmountCell);

            tableBody.appendChild(row);
        });
    }

    fetchBalanceData();

    function formatNumberWithCommas(x) {
        return x.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
    }
});
