import pandas as pd
from sklearn.ensemble import RandomForestClassifier
from sklearn.model_selection import train_test_split
import joblib
import os

MODEL_FILE = 'model.pkl'

def generate_signals(data):
    signals = data.copy()
    signals['signal'] = 0  # 기본값

    # 간단한 전략: 가격이 이동 평균보다 높으면 매수, 낮으면 매도
    signals['short_mavg'] = signals['price'].rolling(window=40, min_periods=1).mean()
    signals['long_mavg'] = signals['price'].rolling(window=100, min_periods=1).mean()
    signals['signal'][signals['short_mavg'] > signals['long_mavg']] = 1
    signals['signal'][signals['short_mavg'] < signals['long_mavg']] = -1

    return signals

def train_model(data):
    data = data.dropna()
    features = data[['price', 'short_mavg', 'long_mavg']]
    labels = data['signal']

    X_train, X_test, y_train, y_test = train_test_split(features, labels, test_size=0.2, random_state=42)

    model = RandomForestClassifier(n_estimators=100, random_state=42)
    model.fit(X_train, y_train)

    accuracy = model.score(X_test, y_test)
    print(f'Model accuracy: {accuracy:.2f}')

    joblib.dump(model, MODEL_FILE)
    return model

def load_model():
    if os.path.exists(MODEL_FILE):
        return joblib.load(MODEL_FILE)
    else:
        return None

def generate_signals_with_model(model, data):
    data = data.dropna()
    features = data[['price', 'short_mavg', 'long_mavg']]
    data['signal'] = model.predict(features)
    return data
