
import requests
import logging
import os
from dotenv import load_dotenv

load_dotenv()
logger = logging.getLogger(__name__)

def get_access_token(config=None):
    url = os.getenv('API_ACCESS_TOKEN_URL', 'https://api.example.com/token')
    headers = {
        'content-type': 'application/x-www-form-urlencoded'
    }
    body = {
        'grant_type': os.getenv('GRANT_TYPE', 'client_credentials'),
        'client_id': os.getenv('CLIENT_ID'),
        'client_secret': os.getenv('CLIENT_SECRET')
    }

    data = '&'.join([f'{key}={value}' for key, value in body.items()])

    logger.info(f"Requesting access token from URL: {url}")
    logger.info(f"Headers: {headers}")
    logger.info(f"Body: {data}")

    response = requests.post(url, headers=headers, data=data)
    logger.info(f"Response status code: {response.status_code}")
    logger.info(f"Response text: {response.text}")

    if response.status_code == 200:
        return response.json().get('access_token')
    else:
        raise Exception(f"Failed to get access token: {response.status_code}, {response.text}")
